summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kaccounttemplateselectordecl.cpp')
-rw-r--r--kmymoney2/widgets/kaccounttemplateselectordecl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
index 795ac29..75f3d16 100644
--- a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
+++ b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
@@ -26,11 +26,11 @@ inline TQString kmm_i18n(const char* msg) { return i18n(msg); }
#include <tqwhatsthis.h>
/*
* Constructs a KAccountTemplateSelectorDecl as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "KAccountTemplateSelectorDecl" );
@@ -26,11 +26,11 @@ inline TQString kmm_i18n(const char* msg) { return i18n(msg); }
#include <tqwhatsthis.h>
/*
- * Constructs a KAccountTemplateSelectorDecl as a child of 'tqparent', with the
+ * Constructs a KAccountTemplateSelectorDecl as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/